@@ -1,6 +1,9 @@
 import circle
 from circle.resources.ach import Ach
 from circle.resources.balances import Balances
+from circle.resources.business_account_deposit_addresses import (
+    BusinessAccountDepositAddress,
+)
 from circle.resources.card import Card
 from circle.resources.error_object import ErrorObject
 from circle.resources.master_wallet import MasterWallet
